# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`thumbor`](#thumbor): Install and configure Thumbor

#### Private Classes

* `thumbor::config`: Setup configuration files for Thumbor
* `thumbor::install`: Install packages and dependencies for Thumbor
* `thumbor::python`: Manage the Python installation
* `thumbor::service`: Manage Thumbor system service and instances
* `thumbor::upgrade`: Upgrade Thumbor's Python venv
* `thumbor::user`: Setup users and groups for Thumbor

### Defined types

* [`thumbor::service::systemd`](#thumborservicesystemd): Setup a Thumbor service instance

## Classes

### <a name="thumbor"></a>`thumbor`

Install and configure Thumbor

#### Parameters

The following parameters are available in the `thumbor` class:

* [`additional_packages`](#additional_packages)
* [`config`](#config)
* [`config_dir`](#config_dir)
* [`ensure`](#ensure)
* [`group`](#group)
* [`plugins`](#plugins)
* [`listen`](#listen)
* [`manage_epel`](#manage_epel)
* [`manage_group`](#manage_group)
* [`manage_python`](#manage_python)
* [`manage_user`](#manage_user)
* [`path`](#path)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`pip_provider`](#pip_provider)
* [`pip_proxyserver`](#pip_proxyserver)
* [`ports`](#ports)
* [`python_config`](#python_config)
* [`security_key`](#security_key)
* [`statefile`](#statefile)
* [`update_enabled`](#update_enabled)
* [`user`](#user)
* [`version`](#version)
* [`venv_path`](#venv_path)

##### <a name="additional_packages"></a>`additional_packages`

Data type: `Array`

Specifies a list of additional packages that are required for thumbor or any of it's dependencies.

##### <a name="config"></a>`config`

Data type: `Hash`

The configuration for Thumbor. Note the hash keys will be converted to upper case.
You can refer to Thumbor wiki for configuration options: https://github.com/thumbor/thumbor/wiki/Configuration

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

Thumbor configuration files are stored in this directory if venv is not used

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Controls the installation and removal of application components (files, user, group), default present

##### <a name="group"></a>`group`

Data type: `String`

Name of the group to install (optional) and under which we run the thumbor service, default thumbor

##### <a name="plugins"></a>`plugins`

Data type: `Variant[Array[String],String]`

Thumbor plugins to install via PIP

##### <a name="listen"></a>`listen`

Data type: `String`

Host address to listen on, default 127.0.0.1

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

If EPEL should be enabled on RHEL-based distributions.

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

If we control the installation of the group, default true

##### <a name="manage_python"></a>`manage_python`

Data type: `Boolean`

If we control the installation of Python, default true

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

If we control the installation of the user, default true

##### <a name="path"></a>`path`

Data type: `String`

Specifies the content of the PATH environment variable when running commands.

##### <a name="package_name"></a>`package_name`

Data type: `String`

Package name of the thumbor application as found in pip, default thumbor

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'absent', 'latest']`

Control the ensure on additional pip installations, default $ensure ('present')

##### <a name="pip_provider"></a>`pip_provider`

Data type: `Optional[String]`

The version of pip to use.

##### <a name="pip_proxyserver"></a>`pip_proxyserver`

Data type: `Optional[String]`

The full url (including credentials) to a proxy server or undef to not use one at all, default undef

##### <a name="ports"></a>`ports`

Data type: `Variant[Array[String],String]`

Array of port strings to let thumbor listen on. This also controls how many instances are spinned up. Default: [ '8000' ]

##### <a name="python_config"></a>`python_config`

Data type: `Hash`

Config for Python that should be used (if $manage_python is enabled)

##### <a name="security_key"></a>`security_key`

Data type: `Optional[String]`

Security key to use in thumbor, default undef

##### <a name="statefile"></a>`statefile`

Data type: `String`

This file contains the version information, it is internally used to determine if a venv upgrade is necessary

##### <a name="update_enabled"></a>`update_enabled`

Data type: `Boolean`

Whether to automatically update the Python venv if necessary. Note that
updates of the Thumbor PIP are controlled by the $version parameter.

##### <a name="user"></a>`user`

Data type: `String`

Name of the user to install (optional) and under which we run the thumbor service, default thumbor

##### <a name="version"></a>`version`

Data type: `String`

Version of Thumbor that should be installed, default 'present'

##### <a name="venv_path"></a>`venv_path`

Data type: `Optional[Stdlib::Absolutepath]`

If we use virtualenv (false if undef) and what path we use as base, default undef

## Defined types

### <a name="thumborservicesystemd"></a>`thumbor::service::systemd`

Setup a Thumbor service instance

#### Parameters

The following parameters are available in the `thumbor::service::systemd` defined type:

* [`port`](#port)

##### <a name="port"></a>`port`

Data type: `String`

The port Thumbor listens on.

Default value: `$name`

